==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PodListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodListBuilder extends io.fabric8.kubernetes.api.model.PodListFluentImpl<io.fabric8.kubernetes.api.model.PodListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PodList,io.fabric8.kubernetes.api.model.PodListBuilder>{
  public PodListBuilder() {
    this(false);
  }
  public PodListBuilder(java.lang.Boolean validationEnabled) {
    this(new PodList(), validationEnabled);
  }
  public PodListBuilder(io.fabric8.kubernetes.api.model.PodListFluent<?> fluent) {
    this(fluent, false);
  }
  public PodListBuilder(io.fabric8.kubernetes.api.model.PodListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodList(), validationEnabled);
  }
  public PodListBuilder(io.fabric8.kubernetes.api.model.PodListFluent<?> fluent,io.fabric8.kubernetes.api.model.PodList instance) {
    this(fluent, instance, false);
  }
  public PodListBuilder(io.fabric8.kubernetes.api.model.PodListFluent<?> fluent,io.fabric8.kubernetes.api.model.PodList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodListBuilder(io.fabric8.kubernetes.api.model.PodList instance) {
    this(instance,false);
  }
  public PodListBuilder(io.fabric8.kubernetes.api.model.PodList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PodListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PodList build() {
    PodList buildable = new PodList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodListBuilder that = (PodListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/PodListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodListBuilder extends PodListFluentImpl<PodListBuilder> implements VisitableBuilder<PodList,PodListBuilder>{
  public PodListBuilder() {
    this(false);
  }
  public PodListBuilder(Boolean validationEnabled) {
    this(new PodList(), validationEnabled);
  }
  public PodListBuilder(PodListFluent<?> fluent) {
    this(fluent, false);
  }
  public PodListBuilder(PodListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodList(), validationEnabled);
  }
  public PodListBuilder(PodListFluent<?> fluent,PodList instance) {
    this(fluent, instance, false);
  }
  public PodListBuilder(PodListFluent<?> fluent,PodList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodListBuilder(PodList instance) {
    this(instance,false);
  }
  public PodListBuilder(PodList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PodListFluent<?> fluent;
  Boolean validationEnabled;
  public PodList build() {
    PodList buildable = new PodList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
